#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ALMOST_GREATER_OR_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ALMOST_GREATER_OR_EQUAL_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/scalar/almost_greater_or_equal.hpp>

#endif
